# Copyright 1999-2007 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $
#
# Maintainer: Toolchain Ninjas <toolchain@gentoo.org>
#
# We install llvm into CTARGET-VERSION specific directories.  This lets
# us easily merge multiple versions for multiple targets (if we wish) and
# then switch the versions on the fly (with `binutils-config`).
#
# llvm-9999           -> live svn
# llvm-9999_preYYMMDD -> nightly snapshot date YYMMDD
# llvm-#              -> normal release

extra_eclass=""
if [[ -n ${LLVM_TYPE} ]] ; then
	LTYPE=${LLVM_TYPE}
else
	case ${PV} in
	9999)      LTYPE="svn";;
	9999_pre*) LTYPE="pre";;
	*)         LTYPE="rel";;
	esac
fi

if [[ ${LTYPE} == "svn" ]] ; then
	extra_eclass="subversion"
	ESVN_REPO_URI="http://llvm.org/svn/llvm-project/llvm/trunk/llvm"
	LVER="svn"
elif [[ ${LTYPE} == "pre" ]] ; then
	LVER=${PV/pre*}
elif [[ ${LTYPE} == "rel" ]] ; then
	LVER=${PV}
else
	LVER=${LLVM_VER}
fi

inherit eutils libtool autotools flag-o-matic gnuconfig multilib ${extra_eclass}
EXPORT_FUNCTIONS src_unpack src_compile src_test src_install pkg_postinst pkg_postrm

export CTARGET=${CTARGET:-${CHOST}}
if [[ ${CTARGET} == ${CHOST} ]] ; then
	if [[ ${CATEGORY/cross-} != ${CATEGORY} ]] ; then
		export CTARGET=${CATEGORY/cross-}
	fi
fi
is_cross() { [[ ${CHOST} != ${CTARGET} ]] ; }

DESCRIPTION="Low Level Virtual Machine"
HOMEPAGE="http://llvm.org/"

case ${LTYPE} in
	svn)  SRC_URI="";;
	pre) SRC_URI="http://llvm.org/prereleases/${LVER}/llvm-${LVER}.tar.gz";;
	rel)
		SRC_URI="http://llvm.org/releases/${PV}/llvm-${PV}.tar.gz"
esac
add_src_uri() {
	[[ -z $2 ]] && return
	local a=$1
	set -- http://ftp.mars.arge.at/pub/
	SRC_URI="${SRC_URI} ${@/%//${a}}"
}
add_src_uri llvm-${PV}-patches-${PATCHVER}.tar.bz2 ${PATCHVER}
add_src_uri llvm-${PV}-uclibc-patches-${UCLIBC_PATCHVER}.tar.bz2 ${UCLIBC_PATCHVER}

LICENSE="|| ( LLVM )"
IUSE="multitarget multislot test vanilla"
if use multislot ; then
	SLOT="${CTARGET}-${LVER}"
elif is_cross ; then
	SLOT="${CTARGET}"
else
	SLOT="0"
fi

if is_cross ; then
	RDEPEND=">=sys-devel/binutils-config-1.9"
else
	RDEPEND=">=sys-devel/binutils-config-1.8-r6"
fi
DEPEND="${RDEPEND}
	test? ( dev-util/dejagnu )
	nls? ( sys-devel/gettext )"

S=${WORKDIR}/llvm
[[ ${LVER} != "svn" ]] && S=${S}-${LVER}

LIBPATH=/usr/$(get_libdir)/llvm/${CTARGET}/${LVER}
INCPATH=${LIBPATH}/include
DATAPATH=/usr/share/llvm-data/${CTARGET}/${LVER}
MY_BUILDDIR=${WORKDIR}/build
if is_cross ; then
	BINPATH=/usr/${CHOST}/${CTARGET}/binutils-bin/${LVER}
else
	BINPATH=/usr/${CTARGET}/binutils-bin/${LVER}
fi

tc-llvm_unpack() {
	unpack ${A}
	mkdir -p "${MY_BUILDDIR}"
	[[ -d ${WORKDIR}/patch ]] && mkdir "${WORKDIR}"/patch/skip
}

tc-llvm_apply_patches() {
	cd "${S}"

	if ! use vanilla ; then
		if [[ -n ${PATCHVER} ]] ; then
			EPATCH_SOURCE=${WORKDIR}/patch
			[[ -n $(ls "${EPATCH_SOURCE}"/*.bz2 2>/dev/null) ]] \
				&& EPATCH_SUFFIX="patch.bz2" \
				|| EPATCH_SUFFIX="patch"
			epatch
		fi
		local check base=${PORTAGE_CONFIGROOT}/etc/portage/patches
		for check in {${CATEGORY}/${PF},${CATEGORY}/${P},${CATEGORY}/${PN}}; do
			EPATCH_SOURCE=${base}/${CTARGET}/${check}
			[[ -r ${EPATCH_SOURCE} ]] || EPATCH_SOURCE=${base}/${CHOST}/${check}
			[[ -r ${EPATCH_SOURCE} ]] || EPATCH_SOURCE=${base}/${check}
			if [[ -d ${EPATCH_SOURCE} ]] ; then
				EPATCH_SUFFIX="patch"
				EPATCH_FORCE="yes" \
				EPATCH_MULTI_MSG="Applying user patches from ${EPATCH_SOURCE} ..." \
				epatch
				break
			fi
		done
	fi

	# Run misc portage update scripts
	cd autoconf
	gnuconfig_update
	aclocal --force -I m4 || die "aclocal failed"
	autoconf --force --warnings=all -o ../configure configure.ac || die "autoconf failed"
	cd ..
	autoheader --warnings=all -I autoconf -I autoconf/m4 autoconf/configure.ac || die "autoheader failed"
	
	rm -rf projects/sample

#	cd projects/sample/autoconf
#	gnuconfig_update
#	aclocal -I ../../../autoconf/m4 || die "aclocal failed"
#	autoconf --warnings=all -o ../configure configure.ac || die "autoconf failed"
#	cd ../../..

}

toolchain-llvm_src_unpack() {
	is_cross && [[ $(binutils-config -V) != binutils-config-1.9* ]] \
		&& die "You need to upgrade your binutils-config to 1.9 or newer"

	tc-llvm_unpack
	tc-llvm_apply_patches
}

toolchain-llvm_src_compile() {
	# prevent makeinfo from running in releases.  it may not always be
	# installed, and older llvm may fail with newer texinfo.
	# besides, we never patch the doc files anyways, so regenerating
	# in the first place is useless. #193364
#	find . '(' -name '*.info' -o -name '*.texi' ')' -print0 | xargs -0 touch -r .

	# make sure we filter $LINGUAS so that only ones that
	# actually work make it through #42033
#	strip-linguas -u */po

	# keep things sane
	strip-flags

	local x
	echo
	for x in CATEGORY CBUILD CHOST CTARGET CFLAGS LDFLAGS ; do
		einfo "$(printf '%10s' ${x}:) ${!x}"
	done
	echo

	cd "${MY_BUILDDIR}"
	local myconf=""
#	use nls \
#		&& myconf="${myconf} --without-included-gettext" \
#		|| myconf="${myconf} --disable-nls"
	use multitarget && myconf="${myconf} --enable-targets=all"
	[[ -n ${CBUILD} ]] && myconf="${myconf} --build=${CBUILD}"
#	is_cross && myconf="${myconf} --with-sysroot=/usr/${CTARGET}"
	myconf="--prefix=/usr \
		--sysconfdir=${LIBPATH}/llvm \
		--host=${CHOST} \
		--target=${CTARGET} \
		--datadir=${DATAPATH} \
		--infodir=${DATAPATH}/info \
		--mandir=${DATAPATH}/man \
		--docdir=${DATAPATH}/doc \
		--bindir=${BINPATH} \
		--libdir=${LIBPATH} \
		--libexecdir=${LIBPATH} \
		--includedir=${INCPATH} \
		--enable-assertions \
		--enable-shared \
		--enable-optimized \
		--enable-pic \
		${myconf} ${EXTRA_ECONF}"
	echo ./configure ${myconf}
	"${S}"/configure ${myconf} || die "configure failed"

	emake all || die "emake failed"

	# only build info pages if we user wants them, and if
	# we have makeinfo (may not exist when we bootstrap)
#	if ! has noinfo ${FEATURES} ; then
#		if type -p makeinfo > /dev/null ; then
#			make info || die "make info failed"
#		fi
#	fi
	# we nuke the manpages when we're left with junk
	# (like when we bootstrap, no perl -> no manpages)
#	find . -name '*.1' -a -size 0 | xargs rm -f

}

toolchain-llvm_src_test() {
	cd "${MY_BUILDDIR}"
	make check || die "check failed :("
}

toolchain-llvm_src_install() {
	local x d

	cd "${MY_BUILDDIR}"
	emake DESTDIR="${D}" install || die
	rm -rf "${D}"/${LIBPATH}/bin

	# Newer versions of llvm get fancy with ${LIBPATH} #171905
	cd "${D}"/${LIBPATH}
	for d in ../* ; do
		[[ ${d} == ../${LVER} ]] && continue
		mv ${d}/* . || die
		rmdir ${d} || die
	done
	
	# move llvm-config /usr/bin
	mkdir -p "${D}"/usr/bin
	mv "${D}"/${BINPATH}/llvm-config "${D}"/usr/bin

	# create compatibility Links
	cd "${D}"/${BINPATH}
	for x in llvm-* ; do
		ln -sf ${x} ${x/llvm-/}
	done
	
	# Now we collect everything intp the proper SLOT-ed dirs
	# When something is built to cross-compile, it installs into
	# /usr/$CHOST/ by default ... we have to 'fix' that :)
	if is_cross ; then
		cd "${D}"/${BINPATH}
		for x in * ; do
			mv ${x} ${x/${CTARGET}-}
		done

		if [[ -d ${D}/usr/${CHOST}/${CTARGET} ]] ; then
			mv "${D}"/usr/${CHOST}/${CTARGET}/include "${D}"/${INCPATH}
			mv "${D}"/usr/${CHOST}/${CTARGET}/lib/* "${D}"/${LIBPATH}/
			rm -r "${D}"/usr/${CHOST}/{include,lib}
		fi
	fi
	insinto ${INCPATH}
	if [[ -d ${D}/${LIBPATH}/lib ]] ; then
		mv "${D}"/${LIBPATH}/lib/* "${D}"/${LIBPATH}/
		rm -r "${D}"/${LIBPATH}/lib
	fi

	# Now, some llvm are tricky and actually provide
	# for multiple TARGETS.  Really, we're talking just
	# 32bit/64bit support (like mips/ppc/sparc).  Here
	# we want to tell binutils-config that it's cool if
	# it generates multiple sets of binutil symlinks.
	# e.g. sparc gets {sparc,sparc64}-unknown-linux-gnu
	local targ=${CTARGET/-*} src="" dst=""
	local FAKE_TARGETS=${CTARGET}
	case ${targ} in
		mips*)    src="mips"    dst="mips64";;
		powerpc*) src="powerpc" dst="powerpc64";;
		s390*)    src="s390"    dst="s390x";;
		sparc*)   src="sparc"   dst="sparc64";;
	esac
	case ${targ} in
		mips64*|powerpc64*|s390x*|sparc64*) targ=${src} src=${dst} dst=${targ};;
	esac
	[[ -n ${src}${dst} ]] && FAKE_TARGETS="${FAKE_TARGETS} ${CTARGET/${src}/${dst}}"

	# Generate an env.d entry for this llvm
	cd "${S}"
	insinto /etc/env.d/binutils
	cat <<-EOF > env.d
		TARGET="${CTARGET}"
		VER="${LVER}"
		LIBPATH="${LIBPATH}"
		FAKE_TARGETS="${FAKE_TARGETS}"
	EOF
	newins env.d ${CTARGET}-${LVER}

	# Punt all the fun stuff if user doesn't want it :)
	has noinfo ${FEATURES} && rm -r "${D}"/${DATAPATH}/info
	has noman ${FEATURES} && rm -r "${D}"/${DATAPATH}/man
	# Trim all empty dirs
	find "${D}" -type d | xargs rmdir >& /dev/null
}

toolchain-llvm_pkg_postinst() {
	# Make sure this ${CTARGET} has a binutils version selected
	[[ -e ${ROOT}/etc/env.d/binutils/config-${CTARGET} ]] && return 0
	binutils-config ${CTARGET}-${LVER}
}

toolchain-llvm_pkg_postrm() {
	local current_profile=$(binutils-config -c ${CTARGET})

	# If no other versions exist, then uninstall for this
	# target ... otherwise, switch to the newest version
	# Note: only do this if this version is unmerged.  We
	#       rerun binutils-config if this is a remerge, as
	#       we want the mtimes on the symlinks updated (if
	#       it is the same as the current selected profile)
	if [[ ! -e ${BINPATH}/ld ]] && [[ ${current_profile} == ${CTARGET}-${LVER} ]] ; then
		local choice=$(binutils-config -l | grep ${CTARGET} | awk '{print $2}')
		choice=${choice//$'\n'/ }
		choice=${choice/* }
		if [[ -z ${choice} ]] ; then
			env -i binutils-config -u ${CTARGET}
		else
			binutils-config ${choice}
		fi
	elif [[ $(CHOST=${CTARGET} binutils-config -c) == ${CTARGET}-${LVER} ]] ; then
		binutils-config ${CTARGET}-${LVER}
	fi
}
